About — oceanum 0.7.2 documentation

# About

# oceanum-python

Library for oceanum.io services

- MIT license

- Documentation: https://oceanum-python.readthedocs.io.

## Features

- Simple pythonic access to the Oceanum datamesh

## Credits

This package was developed by Oceanum Numerical, with input from our development partners and contributors.

## Development Lead

- Oceanum Developers <developers@oceanum.science>

## Contributors

Always looking for feedback and input